import useMainStore from '@/store/useMainStore';
import {
  createRouter,
  createWebHashHistory,
  RouteLocation,
  RouteRecordRaw,
} from 'vue-router';
import NProgress from 'nprogress';

const BaseLayout = () =>
  import(/* webpackChunkName: "BaseLayout" */ '@/layout/BaseLayout');
const ManagementLayout = () =>
  import(
    /* webpackChunkName: "ManagementLayout" */ '@/layout/ManagementLayout'
  );

const routes: RouteRecordRaw[] = [
  {
    path: '/',
    name: 'incident-management',
    component: BaseLayout,
    redirect: '/home',
    children: [
      {
        path: '/home',
        component: () =>
          import(/* webpackChunkName: "home.page" */ '@/views/HomePage'),
        name: '应急处置',
        meta: { title: '应急处置', iconName: 'TableOutlined' },
      },
      {
        path: '/status/:status/detail',
        component: () => import('@/views/IncidentManagementDetail'),
      },
      {
        path: '/status/:status/report',
        component: () => import('@/views/IncidentManagementReport'),
      },
    ],
  },
  {
    path: '/404',
    name: 'Global404',
    meta: { title: '页面不见啦.' },
    component: () => import(/* webpackChunkName: "404" */ '@/views/About'),
  },
  {
    path: '/:pathMatch(.*)*',
    name: 'All',
    redirect: (to: RouteLocation) => {
      return { path: '/404', query: { from: to.path } };
    },
  },
];

const router = createRouter({
  history: createWebHashHistory(),
  routes,
  scrollBehavior(to, from, savedPosition) {
    // 始终滚动到顶部
    return { top: 0 };
  },
});

router.beforeEach(() => {
  NProgress.start();
  const main = useMainStore();
  main.clearReqToken();
});
router.afterEach((to) => {
  NProgress.done();
  document!.title = to.meta.title
    ? to?.meta?.title + ' - 交通运输应急指挥系统'
    : '交通运输应急指挥系统';
});

export default router;
