import axios, { AxiosRequestConfig } from 'axios';
import qs from 'querystring';
import { ElMessage } from 'element-plus';
import useMainStore from '@/store/useMainStore';

const baseURL =
  process.env.NODE_ENV === 'production'
    ? // ? 'http://api.xt.wenhq.top:8083/mock/43/zhdd'
      'http://sqpcbg.xt.wenhq.top:8083/api'
    : '/api';

const CancelToken = axios.CancelToken;
const source = CancelToken.source();

axios.interceptors.request.use((config) => {
  const main = useMainStore();
  config.cancelToken = new axios.CancelToken((cancel) => {
    main.pushReqToken(cancel);
  });
  return config;
});

axios.interceptors.response.use(
  (res) => {
    if (res.status >= 200 && res.status < 300) {
      if (res.data?.code === 200) {
        return res.data;
      }
      if (res.data?.code === 401) {
        ElMessage.error({
          // message: `401. 没有权限访问该接口: ${res.config.url}`,
          message: `401. 没有权限访问该接口`,
        });
        throw Error(res.statusText);
      }
      if (res.data?.code === 404) {
        ElMessage.error({ message: '404. 未找到该接口!' });
        throw Error(res.statusText);
      }
      if (res.data?.code >= 500) {
        ElMessage.error({ message: res.data?.msg ?? '系统异常, 请稍后重试!' });
        throw Error(res.statusText);
      }
    }
    if (res.status === 401) {
      ElMessage.error({
        message: `401. 没有权限访问该接口: ${res.config.url}`,
      });
      throw Error(res.statusText);
    }
    if (res.status === 404) {
      ElMessage.error({ message: '404. 未找到该接口!' });
      throw Error(res.statusText);
    }

    if (res.status >= 500) {
      ElMessage.error({ message: '系统异常, 请稍后重试!' });
      throw Error(res.statusText);
    }
  },
  (error) => {
    // ElMessage.error({ message: '系统异常, 请稍后重试!' });
    throw Error(error);
  },
);

export default function request<T>(
  method: AxiosRequestConfig['method'] = 'GET',
  confifg: AxiosRequestConfig & {},
): Promise<T> {
  return axios.request({
    method,
    baseURL,
    ...confifg,
    headers: {
      Accept: 'application/json',
      'Content-Type': 'application/json',
      Authorization: 'asdd',
      ...confifg.headers,
    },
  });
}
